@@ -116,7 +116,7 @@
 #' Df     = data.frame(y, X)
 #'
 #' # Fit logistic model
-#' FitLog = lrm(y ~ ., Df)
+#' FitLog = glm(y ~ ., Df, family = binomial)
 #'
 #' # Simulate validation data
 #' Xval   = replicate(4, rnorm(5e2))
@@ -223,6 +223,13 @@ val.prob.ci.2 <- function(p, y, logit, group,
   if (!is.numeric(nr.knots)) {
     stop("Nr.knots must be numeric.")
   }
+  if(nr.knots > 5 | nr.knots < 3)
+    stop(paste(
+      "Number of knots = ",
+      nr.knots,
+      sep = "",
+      ", only 3 <= nk <= 5 is allowed."
+    ))
 
   logit <- logit[nma]
   y <- y[nma]
@@ -238,9 +245,9 @@ val.prob.ci.2 <- function(p, y, logit, group,
   y     <- y[order(p)]
   logit <- logit[order(p)]
   p     <- p[order(p)]
+  n     <- length(y)
 
-
-  if (length(p) > 5000 & smooth == "loess") {
+  if (n > 5000 & smooth == "loess") {
     warning("Number of observations > 5000, RCS is recommended. Will perform a preliminary fit to see if any errors occur.", immediate. = TRUE)
     argzLoess$formula = y ~ p
     tmpFit = tryCatch({
@@ -254,7 +261,20 @@ val.prob.ci.2 <- function(p, y, logit, group,
       wmess = c(wmess, tmpmess)
     }
   }
-  if (length(p) > 1000 & CL.BT == TRUE) {
+
+  if(n > 1e5 & smooth %in% c("loess", "RCS")) {
+    warning(
+      "Dataset contains ", format(n, big.mark = " "), " observations. ",
+      "Very large datasets (>100 000 rows) may cause integer overflow errors ",
+      "when using nonparametric methods (e.g., loess or restricted cubic splines). ",
+      "Consider using the logistic calibration framework instead, which is computationally ",
+      "more efficient and stable for large datasets. See the package vignette or documentation ",
+      "for guidance on logistic calibration methods.",
+      immediate. = TRUE
+    )
+  }
+
+  if (n > 1000 & CL.BT == TRUE) {
     warning("Number of observations is > 1000, this could take a while...",
             immediate. = TRUE)
   }
@@ -263,13 +283,12 @@ val.prob.ci.2 <- function(p, y, logit, group,
     # Adjusted 2022-09-26
     P       <- mean(y)
     Intc    <- log(P/(1 - P))
-    n       <- length(y)
-    D       <- -1/n
+    D       <- -1 / n
     L01     <- -2 * sum(y * logit - log(1 + exp(logit)), na.rm = TRUE)
     L.cal   <- -2 * sum(y * Intc - log(1 + exp(Intc)), na.rm = TRUE)
     U.chisq <- L01 - L.cal
     U.p     <- 1 - pchisq(U.chisq, 1)
-    U       <- (U.chisq - 1)/n
+    U       <- (U.chisq - 1) / n
     Q       <- D - U
     cl.auc  <- ci.auc(y, p, cl.level, method.ci)
 
